template<typename Value>
template <typename InputIterator>
inline HashStringCase<Value>::HashStringCase(InputIterator first,
                                             InputIterator beyond)
:
    BaseClass(first, beyond)
{}
