//#include "datetime.ih"
//
//    // supported formats:
//    //
//    //    1: Mon Dec 3 13:29:11 2018
//    //    2: Mon Dec 3 13:29:11 CET 2018
//    //    3: Mon, 3 Dec 2018 13:29:11 +0100
//    //    4: 2018-12-03 13:29:11+01:00
//
//DateTime::Parse DateTime::parseTime(string const &timeStr)
//{
//    istringstream in(timeStr);
//
//    return parseStream(in);
//}
//
