//#include "mailheaders.hh"
//
//MailHeaders::const_hdr_iterator
//MailHeaders::const_hdr_iterator::operator--(int)
//{
//    const_hdr_iterator ret(d_mh, d_current);
//    d_current = lookdown(d_current);
//
//    return ret;
//}
