# This is the configuration file used with the ArgConfig driver program

# This will result in a count of 3 of the check for -o:
option

anything in between is ok

option 12

# Options may have values associated with them. The 'value-option' should
# produce such a value:

value-option this is a value specified with `value-option'
