//                     version.cc

#include "main.ih"

namespace Icmbuild
{
    char version[]  = "0.00";
    char year[]     = "2007";

    char author[] = "Frank B. Brokken (f.b.brokken@rug.nl)";
}
