//#include "cininserter.ih"
//
////namespace
////{
////    bool called = false;
////}
//
//Pipe &CinInserter::childInPipe() // const
//{
////    deprecated__(called, "CinInserter::childInPipe()");
////    return d_inserter->d_pipe;
//
//    return d_oChildInPipe;
//}
//
